TopicMessageHelper class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildAutoTitleFromMessage(
NIMMessage message, {NIMMessage? fallbackMessage}) → String -
buildSummaryText(
NIMMessage? message) → String -
resolveTopicTitle(
V2NIMTopic? topic, {String? fallback}) → String