MediaKitInitializer class
media_kit 初始化管理器。
在 UIKit 内部自动完成初始化,无需外部壳工程调用。 macOS 和 Windows 桌面端使用 media_kit(基于 libmpv / FFmpeg), 支持几乎所有视频编码格式;移动端和 Web 端继续使用 video_player。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
ensureInitialized(
) → void - 确保 media_kit 已初始化。可安全多次调用。