SubLabel class

Constructors

SubLabel({String? subLabel, String? riskDescription, Details? details, bool? isRelatedLabel})
SubLabel.fromJson(Map<String, dynamic> json)
factory

Properties

details Details?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isRelatedLabel bool?
getter/setter pair
riskDescription String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subLabel String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited