SelectedBeam class

选中的会话

Constructors

SelectedBeam({required NIMConversationType type, String? conversationId, String? sessionId, String? name, int? count, String? avatar})

Properties

avatar String?
final
conversationId String?
getter/setter pair
count int?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
getter/setter pair
type → NIMConversationType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override