HistoryReadPositionTracker class

Properties

hashCode int
The hash code for this object.
no setterinherited
lastReadTime int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state HistoryReadPositionState
getter/setter pair

Methods

beginLocation() bool
completeLocation({required bool success}) bool
evaluateTopMessage(int createTime, {bool hasReachedHistoryStart = false}) bool
initialize(int? readTime) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited