MessageReactionConfig class

快捷回复资源的固定索引配置

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

allIndexes List<int>
final
supportedIndexes Set<int>
final

Static Methods

assetPath(int index) String
sortOrder(int index) int

Constants

quickIndexes → const List<int>