MessageReactionState class

一条消息的表情快捷回复状态

Constructors

MessageReactionState({Map<int, MessageReactionSummary> summaries = const <int, MessageReactionSummary>{}, bool loaded = false, bool loading = false, int version = 0})

Properties

hashCode int
The hash code for this object.
no setterinherited
loaded bool
final
loading bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summaries Map<int, MessageReactionSummary>
final
version int
final

Methods

copyWith({Map<int, MessageReactionSummary>? summaries, bool? loaded, bool? loading, int? version}) MessageReactionState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

empty MessageReactionState
final