AitBean class

包装的@信息

Constructors

AitBean({UserInfoWithTeam? teamMember, NIMAIUser? aiUser})

Properties

aiUser ↔ NIMAIUser?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
teamMember ↔ UserInfoWithTeam?
getter/setter pair

Methods

getAccountId() String?
获取用户id
getAvatar() String?
获取头像
getAvatarName() String?
获取图像显示的昵称
getName() String
获取昵称
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited