ChatForwardViewModel class

Inheritance

Constructors

ChatForwardViewModel(List<String>? filterSessions)

Properties

contactList List<ContactInfo>
好友列表
getter/setter pair
contactShowList List<SearchResult<ContactInfo>>
好友显示列表
getter/setter pair
conversationLimit int
final
conversationList List<NIMConversation>
会话列表
getter/setter pair
conversationOffset int
getter/setter pair
conversationShowList List<SearchResult<NIMConversation>>
会话显示列表
getter/setter pair
filterSessions List<String>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hasMoreConversation bool
getter/setter pair
isMultiSelect bool
是否多选
getter/setter pair
recentForwards List<RecentForward>
最近转发列表
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedList List<SelectedBeam>
选中列表
getter/setter pair
teamList List<NIMTeam>
所有的群组
getter/setter pair
teamShowList List<SearchResult<NIMTeam>>
群组显示列表
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addSelected(SelectedBeam selected) → void
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
override
getContactList(String? keyword) → void
获取联系人列表
getConversationCount(String conversationId) int?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeSelected(SelectedBeam selected) → void
searchContactByKeyword(String? keyword) → void
搜索联系人
searchConversationByKeyword(String? keyword) → void
搜索会话
searchTeamByKeyword(String? keyword) → void
搜索群组
setMultiSelect(bool isMultiSelect) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited