ChatSettingViewModel class
- Inheritance
-
- Object
- ChangeNotifier
- ChatSettingViewModel
Constructors
- ChatSettingViewModel(String conversationId)
Properties
- accountId ↔ String
-
getter/setter pair
- conversationId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hasPin → dynamic
-
no setter
- isNotify → dynamic
-
no setter
- isPin → dynamic
-
no setter
- isStick → dynamic
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subscriptions
→ List<
StreamSubscription?> -
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setAIUserPin(
bool addPin) → void -
setNotify(
bool value) → void -
setStick(
bool value) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited